/***********************************************************************************************************
*
*   名称    HAISENHYO.CPP       配線表 編集／印刷
*
***********************************************************************************************************/

#pragma     pack  (1)

struct  HAISENHEDR  {                                                               // 配線表 （ヘッダー部）
        char        systemno[10];                                                   // システムＮｏ
        char        nousaki [22];                                                   // 納入先名称
        char        sakuban [16];                                                   // 作番
        char        banno   [ 6];                                                   // 盤Ｎｏ
        char        comment [80];                                                   // コメント
        int         datacount;                                                      // デーラ数
};


struct  HAISENDATA  {                                                               // 配線表 （データ部）
        int         gyoban;                                                         // 行番
        int         length;                                                         // 線長
        char        senban[10];                                                     // 固有線番
        char        senkei[ 6];                                                     // 線径
        char        sensyu[ 4];                                                     // 線種
        char        kyoku [ 4];                                                     // 極性
        char        kairo [ 6];                                                     // 回路区分
        char        haisen[ 6];                                                     // 配線指定
        char        zahyo1[ 6];                                                     // 自己座標
        char        tansi1[ 6];                                                     //     端子
        char        size1 [ 6];                                                     //     ｻｲｽﾞ
        char        syori1[10];                                                     //     処理
        char        zahyo2[ 6];                                                     // 相手座標
        char        tansi2[ 6];                                                     //     端子
        char        size2 [ 6];                                                     //     ｻｲｽﾞ
        char        syori2[10];                                                     //     処理
        char        sheet [ 8];                                                     // シート番号
};

#pragma     pack  ()



class  CHaisenhyo : public  CPtrnDisp
{
    protected:
        virtual void    PtrnInitFunc    ();
        virtual void    PtrnMesgFunc    (int);
        virtual BOOL    PtrnKeyStart    (PTRNDATA*);
        virtual void    PtrnKeyFunc     (int, int, PTRNDATA*);

    private:    int     DispDtno;
                void    DispDataSet     (int);
                void    DispDataGet     ();

    private:    int     SortCulm;
				int		SortFlag;
                void    SortDispData    (int);
};


extern  HAISENHEDR      HaisenHedr;                                                 // 配線表 （ヘッダー部）
extern  HAISENDATA*     HaisenData;                                                 // 配線表 （データ部）
extern  int*            HaisenIndx;                                                 // 配線表 （インデックス）


