/***********************************************************************************************************
*
*   名称    TESTDISP.H      テスト画面
*
***********************************************************************************************************/

class  CPtrnTest1 : public  CPtrnDisp                                               // テスト画面１ （図形）
{
    protected:
        virtual void    PtrnInitFunc    ();
        virtual void    PtrnTimrFunc    ();
        virtual void    PtrnMesgFunc    (int);

    private:    int     Timr_Mark[20];
};



class  CPtrnTest2 : public  CPtrnDisp                                               // テスト画面２ （文字列・ボタン）
{
    protected:
        virtual void    PtrnInitFunc    ();
        virtual void    PtrnMesgFunc    (int);
};



class  CPtrnTest3 : public  CPtrnDisp												// テスト画面３ （表・キー入力）
{
    protected:
        virtual void    PtrnInitFunc    ();
        virtual void    PtrnExitFunc    ();
        virtual void    PtrnMesgFunc    (int);
        virtual void    PtrnKeyFunc     (int, int, PTRNDATA*);

    protected:  void    PrintHaisenhyo  ();
                void    InitHaisenhyo   ();
};



class  CPtrnTest4 : public  CPtrnDisp												// テスト画面４ （グラフ）
{
    protected:
        virtual void    PtrnInitFunc    ();
        virtual void    PtrnDispFunc    (CDraw*, int);

    protected:  RECT	rect;
                int     timr;
                int     cont;
                int     data1[100];
                int     data2[100];
                int     data3[100];
                int     data4[100];
                int     data5[100];
};



class  CPtrnTest5 : public  CPtrnDisp												// テスト画面５ （マウス操作）
{
    protected:
        virtual void    PtrnInitFunc    ();
        virtual void    PtrnMesgFunc    (int);
        virtual void    PtrnRbtnFunc    (int);
        virtual BOOL    PtrnMouseFunc   (POINT, int, int);
};
