#define     SYSTEM                  0
#define     BANNO                   100
#define     BUTTON                  101
#define     CHECKBOX                106
#define     COMENT                  109
#define     DAEN                    110
#define     GRAPH                   111
#define     GRAPH_LINE              112
#define     GRAPH_RECT              113
#define     HANTEN                  114
#define     HYO_DATA                117
#define     HYO_RECT                432
#define     H_SCROLL                433
#define     INSATSU                 434
#define     KAHENMOJI               435
#define     KOTEIMOJI               436
#define     KUKEI                   437
#define     LINE                    438
#define     LINENO                  439
#define     MARK                    454
#define     MOUSE_BUTTON1           468
#define     MOUSE_BUTTON2           469
#define     MOUSE_BUTTON3           470
#define     MOUSE_BUTTON4           471
#define     MOUSE_RECT1             472
#define     MOUSE_RECT2             477
#define     MOUSE_SELECT            482
#define     NOUNYUSAKI              485
#define     PAGE1                   486
#define     PAGE2                   487
#define     P_BANNO                 488
#define     P_COMMENT               489
#define     P_HAISENSITEI           490
#define     P_KAIROKUBUN            552
#define     P_KOYUSENBAN            614
#define     P_KYOKUSEI              676
#define     P_LINENO                738
#define     P_NOUNYUSAKI            800
#define     P_SAKUBAN               801
#define     P_SENCYO                802
#define     P_SENKEI                864
#define     P_SENSYU                926
#define     P_SHEETNO               988
#define     P_SIZE1                 1050
#define     P_SIZE2                 1112
#define     P_SYORI1                1174
#define     P_SYORI2                1236
#define     P_SYSTEMNO              1298
#define     P_TANSI1                1299
#define     P_TANSI2                1361
#define     P_ZAHYO1                1423
#define     P_ZAHYO2                1485
#define     RADIOBUTTON             1547
#define     SAKUBAN                 1548
#define     SUUCHI                  1549
#define     SYSTEMNO                1550
#define     TENMETSU                1551
#define     TOUROKU                 1554
#define     T_HAISEN                1555
#define     T_KAIROKUBUN            1556
#define     T_KOYUSENBAN            1557
#define     T_KYOKUSEI              1558
#define     T_SENCYO                1559
#define     T_SENKEI                1560
#define     T_SENSYU                1561
#define     T_SHEETNO               1562
#define     T_SIZE1                 1563
#define     T_SIZE2                 1564
#define     T_SYORI1                1565
#define     T_SYORI2                1566
#define     T_TANSHI1               1567
#define     T_TANSHI2               1568
#define     T_ZAHYO1                1569
#define     T_ZAHYO2                1570
#define     V_SCROLL                1571
