#include	"TEST.h"
#include	<string.h>


BOOL  UserInit ()
{
	return TRUE;
}


void  UserExit ()
{
}


void  UserTimr ()
{
    static  int  timr = 0;
    static  int  data = 0;
    static  int  colr = 0;

    if (++timr >= 100) timr = 0;

	if ((timr % 10) == 0) {															// １杪周期
	    if (++data >= 100) data = 0;
        Set_iData(GRAPH,  data);
        Set_iData(SUUCHI, data);
        if (data >= 50) Set_Color(GRAPH, 1);
        else            Set_Color(GRAPH, 0);
	}

	if ((timr % 50) == 0) {															// ５杪周期
        if (++colr == 4) colr = 0;
        Set_wData(LINE,  colr);
        Set_wData(KUKEI, colr);
        Set_wData(DAEN,  colr);
    }
}


CPtrnDisp*  GetPtrnWnd (const char* name)
{
	if (strcmp(name, "テスト  ［メニュー選択］")        == 0) return (new CPtrnDisp());
	if (strcmp(name, "システム終了")                    == 0) return (new CPtrnDisp());
	if (strcmp(name, "テスト  （図形）")                == 0) return (new CPtrnTest1());
	if (strcmp(name, "テスト  （マウス操作）")          == 0) return (new CPtrnTest5());
	if (strcmp(name, "子ウィンドウ (1)")                == 0) return (new CPtrnDisp());
	if (strcmp(name, "子ウィンドウ (2)")                == 0) return (new CPtrnDisp());
	if (strcmp(name, "子ウィンドウ (3)")                == 0) return (new CPtrnDisp());
	if (strcmp(name, "ポップアップメニュー")            == 0) return (new CPtrnDisp());
	if (strcmp(name, "テスト  （文字列・ボタン）")      == 0) return (new CPtrnTest2());
	if (strcmp(name, "テスト  （グラフ）")              == 0) return (new CPtrnTest4());
	if (strcmp(name, "テスト  （表・キー入力）")        == 0) return (new CPtrnTest3());
	if (strcmp(name, "テスト  （表）")                  == 0) return (new CHaisenhyo());
	return NULL;
}
